SystemOrganization addCategory: #'ElasticSearch-Tests'!

TestCase subclass: #ESAnalysisTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESAnalysisTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:46'!
testAnalyzerFilterTokenizerCharFilter
	| analyzer analysis |
	analyzer := ESStandardAnalyzer new
		name: 'std';
		yourself.
	analysis := ESAnalysis new
		addAnalyzer: analyzer;
		yourself.
	self assert: analysis jsonContent asJsonString equals: '{"analyzer":{"std":{"type":"standard"}}}'! !

!ESAnalysisTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:44'!
testBasic
	| analyzer analysis |
	analyzer := ESStandardAnalyzer new
		name: 'std';
		yourself.
	analysis := ESAnalysis new
		addAnalyzer: analyzer;
		yourself.
	self assert: analysis jsonContent asJsonString equals:'{"analyzer":{"std":{"type":"standard"}}}'! !

TestCase subclass: #ESAnalyzerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESAnalyzerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:44'!
testCustomAnalyzer
	| analyzer |
	analyzer := ESCustomAnalyzer new.
	analyzer
		name: 'partial_word';
		tokenizer: 'standard';
		filter: (Array with: 'my_nGram');
		charFilter: (Array with: 'myCharFilter').
	self assert: analyzer jsonContent asJsonString equals: '{"type":"custom","tokenizer":"standard","filter":["my_nGram"],"char_filter":["myCharFilter"]}'! !

!ESAnalyzerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:45'!
testStandardAnalyzer
	| analyzer |
	analyzer := ESStandardAnalyzer new name: 'std'.
	self assert: analyzer jsonContent asJsonString equals: '{"type":"standard"}'! !

TestCase subclass: #ESIndexDependentTests
	instanceVariableNames: 'index'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

ESIndexDependentTests subclass: #ESDocumentDependentTests
	instanceVariableNames: 'document'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESDocumentDependentTests methodsFor: 'convenience' stamp: 'PaulDeBruicker 4/23/2013 11:14'!
newDocument
	| dict |
	dict := Dictionary new.
	dict at: 'message' put: 'this is the documents content'.
	dict at: 'user' put: 'Mr T'.
	^ ESDocument withContent: dict! !

!ESDocumentDependentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/23/2013 11:14'!
setUp
	super setUp.
	document := self newDocument! !

ESDocumentDependentTests subclass: #ESDocumentTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESDocumentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 17:13'!
testAddDocument
	document addToIndex: index.
	self assert: document hasId.
	self assert: document hasVersion! !

!ESDocumentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 17:14'!
testGetDocument
	| retrievedDocument |
	document addToIndex: index.
	self assert: document hasId.
	self assert: document hasVersion.
	retrievedDocument := index getDocument: document.
	self assert: document equals: retrievedDocument! !

ESDocumentDependentTests subclass: #ESSearchTests
	instanceVariableNames: 'search'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/26/2013 08:51'!
createSearch
	search := ESSearch index: index! !

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/24/2013 07:59'!
setUp
	super setUp.
	document addToIndex: index.
	self createSearch.
	(Delay forMilliseconds: 1000) wait	"need to give the index time to index the document. or something"! !

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/27/2013 09:04'!
testQueryStringSearch
	search
		addQuery: (ESQueryStringQuery forString: 'documents');
		search.
	self assert: search results notEmpty.
	self assert: (search results first content at: 'user') equals: 'Mr T'! !

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/27/2013 09:05'!
testSearchUsingFuzzyLikeThisQuery
	| query |
	query := ESFuzzyLikeThisQuery new query: 'documents'.
	search
		addQuery: query;
		search.
	self assert: search results notEmpty.
	self assert: (search results first content at: 'user') equals: 'Mr T'! !

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/27/2013 09:05'!
testSearchUsingMatchQuery
	| query |
	query := ESMatchQuery new query: 'documents'.
	search
		addQuery: query;
		search.
	self assert: search results notEmpty.
	self assert: (search results first content at: 'user') equals: 'Mr T'! !

!ESSearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/27/2013 09:05'!
testSearchUsingMoreLikeThisQuery
	| query |
	query := ESMoreLikeThisQuery new query: 'documents'.
	self newDocument addToIndex: index.
	search
		addQuery: query;
		search.
	self assert: search results notEmpty.
	self assert: (search results first content at: 'user') equals: 'Mr T'! !

ESSearchTests subclass: #ESURISearchTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESURISearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/26/2013 08:51'!
createSearch
	search := ESURISearch index: index! !

!ESURISearchTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/26/2013 08:52'!
testURISearch
	search
		queryString: 'documents';
		search.
	self assert: search results notEmpty.
	self assert: (search results first content at: 'message') equals: 'this is the documents content'! !

!ESIndexDependentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 14:46'!
deleteIndex
	ESIndex deleteIndex: self indexName! !

!ESIndexDependentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 14:46'!
indexName
	^ 'test-index'! !

!ESIndexDependentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 14:46'!
setUp
	super setUp.
	index := ESIndex createIndex: self indexName! !

!ESIndexDependentTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/22/2013 14:46'!
tearDown
	self deleteIndex! !

ESIndexDependentTests subclass: #ESIndexTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESIndexTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 17:07'!
testCreateIndex
	| mapping analysis properties |
	index
		shards: 34;
		replicas: 19.
	analysis := ESAnalysis new
		addAnalyzer:
			(ESStandardAnalyzer new
				name: 'std';
				yourself).
	index analysis: analysis.
	mapping := ESMapping new.
	properties := ESMappingProperties new
		name: 'mp';
		addProperty:
				(ESStringMappingProperty new
						name: 'message';
						indexAnalyzer: 'partial_word';
						store: 'yes';
						searchAnalyzer: 'full_word';
						yourself).
	mapping addMappingProperty: properties.
	index mapping: mapping.
	self assert: index indexCreationJsonSettings equals:'{"mappings":{"mp":{"properties":{"message":{"store":"yes","index_analyzer":"partial_word","search_analyzer":"full_word","type":"string"}}}},"settings":{"shards":34,"analysis":{"analyzer":{"std":{"type":"standard"}}},"replicas":19}}'! !

TestCase subclass: #ESMappingPropertiesTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESMappingPropertiesTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 17:06'!
testStringProperty
	| prop properties |
	prop := ESStringMappingProperty new
		name: 'message';
		indexAnalyzer: 'partial_word';
		store: 'yes';
		searchAnalyzer: 'full_word'.
	properties := ESMappingProperties new.
	properties
		addProperty: prop;
		name: 'tweet'.
	self
		assert: properties jsonContent asJsonString
		equals:'{"properties":{"message":{"store":"yes","index_analyzer":"partial_word","search_analyzer":"full_word","type":"string"}}}'! !

TestCase subclass: #ESMappingPropertyTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESMappingPropertyTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 17:06'!
testStringProperty
	| prop |
	prop := ESStringMappingProperty new
		name: 'message';
		indexAnalyzer: 'partial_word';
		store: 'yes';
		searchAnalyzer: 'full_word'.
	self
		assert: prop jsonContent asJsonString
		equals:'{"store":"yes","index_analyzer":"partial_word","search_analyzer":"full_word","type":"string"}'! !

TestCase subclass: #ESMappingTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESMappingTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 17:06'!
testStringProperty
	| prop properties mapping |
	prop := ESStringMappingProperty new
		name: 'message';
		indexAnalyzer: 'partial_word';
		store: 'yes';
		searchAnalyzer: 'full_word'.
	properties := ESMappingProperties new.
	properties
		addProperty: prop;
		name: 'tweet'.
	mapping := ESMapping new
		addMappingProperty: properties;
		yourself.
	self
		assert: mapping jsonContent asJsonString
		equals:
			'{"tweet":{"properties":{"message":{"store":"yes","index_analyzer":"partial_word","search_analyzer":"full_word","type":"string"}}}}'! !

TestCase subclass: #ESMatchQueryTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESMatchQueryTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/29/2013 16:09'!
testModifiedJson
	self
		assert:
			(ESMatchQuery new
				query: 'donkey';
				fuzziness: 0.5;
				field: 'message';
				matchPhrasePrefix;
				yourself) asJsonString
		equals: '"query": {"match":{"message":{"fuzziness":0.5,"type":"phrase_prefix","query":"donkey"}}}'! !

!ESMatchQueryTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/29/2013 16:09'!
testSimpleJson
	self
		assert:
			(ESMatchQuery new
				query: 'donkey';
				field: 'message';
				yourself) asJsonString
		equals:'"query": {"match":{"message":"donkey"}}'! !

TestCase subclass: #ESQueryStringQueryTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESQueryStringQueryTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/29/2013 16:10'!
testSimpleStringQueryAsRequestBody
	| query |
	query := ESQueryStringQuery forString: 'donkey'.
	self assert: query asJsonString equals: '"query": {"query_string":{"query":"donkey"}}'! !

!ESQueryStringQueryTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 4/23/2013 11:46'!
testSimpleStringQueryAsURIRequest
	| query |
	query := ESQueryStringQuery forString: 'donkey'.
	self assert: query asQueryString equals: 'q=donkey'! !

TestCase subclass: #ESTokenFilterTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESTokenFilterTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:45'!
testNGram
	| ngram |
	ngram := ESNGramTokenFilter new
		name: 'my_nGram';
		maxGram: 20;
		yourself.
	self assert: ngram jsonContent asJsonString equals:'{"type":"nGram","max_gram":20}'! !

TestCase subclass: #ESTokenizerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ElasticSearch-Tests'!

!ESTokenizerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/6/2013 16:45'!
testWhitespace
	| wsp |
	wsp := ESWhitespaceTokenizer new
		name: 'whitespace_tokenizer';
		yourself.
	self assert: wsp jsonContent asJsonString equals:'{"type":"whitespace"}'! !
